"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const ui_1 = require("@sewing-kit/ui");
const plugins_1 = require("@sewing-kit/plugins");
function createCompileBabelStep(pkg, api, config, options) {
    return ui_1.createStep(async (step) => {
        const { configFile = 'babel.js', outputPath } = options;
        const babelConfigPath = api.configPath(`build/packages/${pkg.name}/${configFile}`);
        if (config.babelConfig == null || config.babelIgnorePatterns == null) {
            throw new plugins_1.MissingPluginError('@sewing-kit/plugin-babel');
        }
        const [babelConfig, babelIgnorePatterns] = await Promise.all([
            config.babelConfig.promise({}),
            config.babelIgnorePatterns.promise([]),
        ]);
        await api.write(babelConfigPath, `module.exports=${JSON.stringify(babelConfig)};`);
        const extensions = await config.extensions.promise([]);
        const sourceRoot = path_1.resolve(pkg.root, 'src');
        await step.exec('node_modules/.bin/babel', [
            sourceRoot,
            ...plugins_1.toArgs({
                outDir: outputPath,
                configFile: babelConfigPath,
                verbose: true,
                noBabelrc: true,
                babelConfig: false,
                extensions: extensions.join(','),
                ignore: babelIgnorePatterns.length > 0
                    ? babelIgnorePatterns.join(',')
                    : undefined,
            }, { dasherize: true }),
        ]);
    });
}
exports.createCompileBabelStep = createCompileBabelStep;
